#ifndef _SKILLFLAGS_H_
#define _SKILLFLAGS_H_

#define SKILLFLAG_REQTARGET    0
#define SKILLFLAG_OPTTARGET    1
#define SKILLFLAG_ONLYIND      2
#define SKILLFLAG_NOIND        3
#define SKILLFLAG_ONCORPSE     4
#define SKILLFLAG_REQDEX       5
#define SKILLFLAG_REQINTEL     6
#define SKILLFLAG_MUSTSTAND    7
#define SKILLFLAG_PASSSTRING   8
#define SKILLFLAG_GIVEEXP      9
#define SKILLFLAG_ONSELF       10

#ifdef COMMANDS_C

char *skillflagnames[] = {"ReqTarget", "OptTarget", "OnlyInd", "NoInd",  
       "OnCorpse", "Unused1", "Unused2", "MustStand", "PassString", 
       "GiveExp", "OnSelf", NULL};

#else

extern char *skillflagnames[];

#endif
#endif




